# problexity

[![Travis Status](https://travis-ci.org/w4k2/problem-complexity.svg?branch=master)](https://travis-ci.org/w4k2/problem-complexity)
[![Documentation Status](https://readthedocs.org/projects/problem-complexity/badge/?version=latest)](http://problem-complexity.readthedocs.io)
[![PyPI version](https://badge.fury.io/py/problem-complexity.svg)](https://badge.fury.io/py/problem-complexity)

The `problexity` module is a ...

## Citation policy

If you use problexity in a scientific publication, I would appreciate citation to the following paper:

```
@article{komorniczak2022complexity,
  title={problexity--open-source Python library for ...},
  author={Komorniczak, Joanna},
  journal={arXiv preprint arXiv:XXXX.YYYYY},
  year={2022}
}
```

## Quick start guide

### Installation

To use the `problexity` package, it will be absolutely useful to install it. Fortunately, it is available in the *PyPI* repository, so you may install it using `pip`:

```shell
pip3 install -U problexity
```

You can also install the module cloned from Github using the setup.py file if you have a strange, but perhaps legitimate need:

```shell
git clone https://github.com/w4k2/problexity.git
cd problexity
make install
```

### Usage

...
